GridConfig class

网格配置

Constructors

GridConfig({bool visible = true, double range = 10.0, double step = 1.0, Color color = const Color(0x44888888)})
const

Properties

color Color
网格颜色
final
hashCode int
The hash code for this object.
no setteroverride
range double
网格范围(单位:米)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
step double
网格步长
final
visible bool
是否显示网格
final

Methods

copyWith({bool? visible, double? range, double? step, Color? color}) GridConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override