PcdParser class

PCD parser interface

Constructors

PcdParser()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

initialize() Future<void>
Initialize the Rust library
parsePcd(String path) Future<List<Point3D>>
Parse PCD file and return list of 3D points
parsePcdWithOptimization(String path, OptimizationOptions options) Future<ParseResult>
Parse PCD file with optimization options