CameraConfig class

相机初始配置

Constructors

CameraConfig({double rotationX = -0.3, double rotationY = 0.5, double zoom = 1.0, double panX = 0, double panY = 0, double minZoom = 0.1, double maxZoom = 10.0})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
maxZoom double
最大缩放
final
minZoom double
最小缩放
final
panX double
初始横向平移
final
panY double
初始纵向平移
final
rotationX double
初始旋转 X 角度(弧度)
final
rotationY double
初始旋转 Y 角度(弧度)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zoom double
初始缩放
final

Methods

copyWith({double? rotationX, double? rotationY, double? zoom, double? panX, double? panY, double? minZoom, double? maxZoom}) CameraConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override