ParseResult class
Result of point cloud parsing with optimization statistics.
Constructors
-
ParseResult({required List<
Point3D> points, required int originalCount, required int finalCount}) -
const
Properties
- finalCount → int
-
Final point count after optimization
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- originalCount → int
-
Original point count
final
-
points
→ List<
Point3D> -
Parsed points
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override